# Schemas

Here you will find the specification for LCAx.
The specification is provided both as JSON Schemas and Python classes with Pydantic.

## LCAx

=== "Python"

    ```python
    {!> schemas/lcax.py!}
    ```

=== "JSON Schema"

    ```json
    {!> schemas/lcax.schema.json!}
    ```

## Download

**Python**
- [LCAx](./schemas/lcax.py)

**JSON Schema**
- [LCAx](./schemas/lcax.schema.json)
